=======
justice
=======


.. image:: https://img.shields.io/pypi/v/justice.svg
        :target: https://pypi.python.org/pypi/justice

.. image:: https://img.shields.io/travis/SukiCZ/justice.svg
        :target: https://travis-ci.com/SukiCZ/justice

.. image:: https://readthedocs.org/projects/justice/badge/?version=latest
        :target: https://justice.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/SukiCZ/justice/shield.svg
     :target: https://pyup.io/repos/github/SukiCZ/justice/
     :alt: Updates



A python package to download company information from https://justice.cz/


* Free software: MIT license
* Documentation: https://justice.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
